@@ -3,6 +3,7 @@
 import pluggy
 
 from alfasim_sdk._internal import version
+from alfasim_sdk._internal.alfasim_sdk_utils import get_metadata
 from alfasim_sdk._internal.units import register_units
 
 # Package information
@@ -83,6 +84,7 @@ from alfasim_sdk._internal.alfacase.case_description import (
 from alfasim_sdk._internal.alfacase.case_description import (
     InternalNodePropertiesDescription,
 )
+from alfasim_sdk._internal.alfacase.case_description import LeakEquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import (
     LengthAndElevationDescription,
 )
@@ -102,6 +104,7 @@ from alfasim_sdk._internal.alfacase.case_description import (
 from alfasim_sdk._internal.alfacase.case_description import OpenHoleDescription
 from alfasim_sdk._internal.alfacase.case_description import PackerDescription
 from alfasim_sdk._internal.alfacase.case_description import PhysicsDescription
+from alfasim_sdk._internal.alfacase.case_description import PigEquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import PipeDescription
 from alfasim_sdk._internal.alfacase.case_description import PipeSegmentsDescription
 from alfasim_sdk._internal.alfacase.case_description import (
@@ -145,6 +148,9 @@ from alfasim_sdk._internal.alfacase.case_description import (
     SeparatorNodePropertiesDescription,
 )
 from alfasim_sdk._internal.alfacase.case_description import SpeedCurveDescription
+from alfasim_sdk._internal.alfacase.case_description import (
+    SurgeVolumeOptionsDescription,
+)
 from alfasim_sdk._internal.alfacase.case_description import TableIPRDescription
 from alfasim_sdk._internal.alfacase.case_description import TablePumpDescription
 from alfasim_sdk._internal.alfacase.case_description import (
@@ -158,7 +164,14 @@ from alfasim_sdk._internal.alfacase.case_description import TracersDescription
 from alfasim_sdk._internal.alfacase.case_description import (
     TracersMassFractionsContainerDescription,
 )
-from alfasim_sdk._internal.alfacase.case_description import TrendOutputDescription
+from alfasim_sdk._internal.alfacase.case_description import (
+    TrendsOutputDescription,
+    PositionalPipeTrendDescription,
+    OverallPipeTrendDescription,
+    GlobalTrendDescription,
+    EquipmentTrendDescription,
+    SeparatorTrendDescription,
+)
 from alfasim_sdk._internal.alfacase.case_description import TubingDescription
 from alfasim_sdk._internal.alfacase.case_description import ValveEquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import (
@@ -172,6 +185,14 @@ from alfasim_sdk._internal.alfacase.case_description import WallLayerDescription
 from alfasim_sdk._internal.alfacase.case_description import WellDescription
 from alfasim_sdk._internal.alfacase.case_description import XAndYDescription
 
+from alfasim_sdk._internal.alfacase.case_description import (
+    ControllerNodePropertiesDescription,
+)
+from alfasim_sdk._internal.alfacase.case_description import (
+    ControllerInputSignalPropertiesDescription,
+    ControllerOutputSignalPropertiesDescription,
+)
+
 # ALFACase: Utilities
 from alfasim_sdk._internal.alfacase.alfacase import convert_alfacase_to_description
 from alfasim_sdk._internal.alfacase.alfacase import convert_description_to_alfacase
@@ -184,28 +205,34 @@ from alfasim_sdk._internal.alfacase.alfatable import (
 # Constants
 from alfasim_sdk._internal.constants import BUBBLE_FIELD
 from alfasim_sdk._internal.constants import CompressorSpeedType
+from alfasim_sdk._internal.constants import ControllerType
 from alfasim_sdk._internal.constants import CorrelationPackage
 from alfasim_sdk._internal.constants import CorrelationPackageType
 from alfasim_sdk._internal.constants import DEFAULT_TEMPERATURE_IN_K
+from alfasim_sdk._internal.constants import DrainageRateMode
 from alfasim_sdk._internal.constants import DROPLET_FIELD
-from alfasim_sdk._internal.constants import EXTRAS_REQUIRED_VERSION_KEY
 from alfasim_sdk._internal.constants import EmulsionModelType
 from alfasim_sdk._internal.constants import EnergyModel
 from alfasim_sdk._internal.constants import EnergyModelPrimaryVariable
 from alfasim_sdk._internal.constants import EquationOfStateType
 from alfasim_sdk._internal.constants import EvaluationStrategyType
+from alfasim_sdk._internal.constants import EXTRAS_REQUIRED_VERSION_KEY
+from alfasim_sdk._internal.constants import FlashModel
+from alfasim_sdk._internal.constants import FlowDirection
 from alfasim_sdk._internal.constants import FLUID_GAS
 from alfasim_sdk._internal.constants import FLUID_OIL
 from alfasim_sdk._internal.constants import FLUID_PHASE_NAMES
 from alfasim_sdk._internal.constants import FLUID_WATER
-from alfasim_sdk._internal.constants import FlashModel
-from alfasim_sdk._internal.constants import FlowDirection
 from alfasim_sdk._internal.constants import GAS_FIELD
 from alfasim_sdk._internal.constants import GAS_LAYER
 from alfasim_sdk._internal.constants import GAS_PHASE
+from alfasim_sdk._internal.constants import GasLiftValveOpeningType
 from alfasim_sdk._internal.constants import HydrodynamicModelType
 from alfasim_sdk._internal.constants import InitialConditionStrategyType
 from alfasim_sdk._internal.constants import InterpolationType
+from alfasim_sdk._internal.constants import LeakLocation
+from alfasim_sdk._internal.constants import LeakModel
+from alfasim_sdk._internal.constants import LeakType
 from alfasim_sdk._internal.constants import MassInflowSplitType
 from alfasim_sdk._internal.constants import MassSourceType
 from alfasim_sdk._internal.constants import MaterialType
@@ -217,18 +244,21 @@ from alfasim_sdk._internal.constants import OIL_LAYER
 from alfasim_sdk._internal.constants import OIL_PHASE
 from alfasim_sdk._internal.constants import OutputAttachmentLocation
 from alfasim_sdk._internal.constants import PVTCompositionalViscosityModel
+from alfasim_sdk._internal.constants import PigRoutingMode
+from alfasim_sdk._internal.constants import PigTrappingMode
 from alfasim_sdk._internal.constants import (
     PipeEnvironmentHeatTransferCoefficientModelType,
 )
 from alfasim_sdk._internal.constants import PipeThermalModelType
 from alfasim_sdk._internal.constants import PipeThermalPositionInput
 from alfasim_sdk._internal.constants import PumpType
-from alfasim_sdk._internal.constants import SOLID_PHASE
 from alfasim_sdk._internal.constants import SeparatorGeometryType
 from alfasim_sdk._internal.constants import SimulationModeType
 from alfasim_sdk._internal.constants import SimulationRegimeType
+from alfasim_sdk._internal.constants import SOLID_PHASE
 from alfasim_sdk._internal.constants import SolidsModelType
 from alfasim_sdk._internal.constants import SurfaceTensionType
+from alfasim_sdk._internal.constants import SurgeVolumeTimeMode
 from alfasim_sdk._internal.constants import TableInputType
 from alfasim_sdk._internal.constants import TracerModelType
 from alfasim_sdk._internal.constants import ValveOpeningType
@@ -265,6 +295,7 @@ from alfasim_sdk._internal.types import AddLayer
 from alfasim_sdk._internal.types import UpdateLayer
 
 # Plugins: Types  for UI customization
+from alfasim_sdk._internal.types import BaseField
 from alfasim_sdk._internal.types import Boolean
 from alfasim_sdk._internal.types import Enum
 from alfasim_sdk._internal.types import FileContent
@@ -296,6 +327,10 @@ __all__ = [
     "CompositionDescription",
     "CompressorEquipmentDescription",
     "CompressorPressureTableDescription",
+    "ControllerNodePropertiesDescription",
+    "ControllerInputSignalPropertiesDescription",
+    "ControllerOutputSignalPropertiesDescription",
+    "ControllerType",
     "CvTableDescription",
     "EnvironmentDescription",
     "EnvironmentPropertyDescription",
@@ -316,6 +351,8 @@ __all__ = [
     "InitialVolumeFractionsDescription",
     "InternalNodePropertiesDescription",
     "LengthAndElevationDescription",
+    "LeakEquipmentDescription",
+    "LeakLocation",
     "LightComponentDescription",
     "LinearIPRDescription",
     "MassSourceEquipmentDescription",
@@ -326,6 +363,9 @@ __all__ = [
     "OpenHoleDescription",
     "PackerDescription",
     "PhysicsDescription",
+    "PigEquipmentDescription",
+    "PigRoutingMode",
+    "PigTrappingMode",
     "PipeDescription",
     "PipeSegmentsDescription",
     "PressureContainerDescription",
@@ -345,6 +385,7 @@ __all__ = [
     "ReservoirInflowEquipmentDescription",
     "SeparatorNodePropertiesDescription",
     "SpeedCurveDescription",
+    "SurgeVolumeOptionsDescription",
     "TableIPRDescription",
     "TablePumpDescription",
     "TemperaturesContainerDescription",
@@ -352,7 +393,12 @@ __all__ = [
     "TracerModelConstantCoefficientsDescription",
     "TracersDescription",
     "TracersMassFractionsContainerDescription",
-    "TrendOutputDescription",
+    "TrendsOutputDescription",
+    "PositionalPipeTrendDescription",
+    "OverallPipeTrendDescription",
+    "GlobalTrendDescription",
+    "EquipmentTrendDescription",
+    "SeparatorTrendDescription",
     "TubingDescription",
     "ValveEquipmentDescription",
     "VelocitiesContainerDescription",
@@ -371,6 +417,7 @@ __all__ = [
     "CorrelationPackage",
     "CorrelationPackageType",
     "DEFAULT_TEMPERATURE_IN_K",
+    "DrainageRateMode",
     "DROPLET_FIELD",
     "EXTRAS_REQUIRED_VERSION_KEY",
     "EmulsionModelType",
@@ -387,9 +434,14 @@ __all__ = [
     "GAS_FIELD",
     "GAS_LAYER",
     "GAS_PHASE",
+    "GasLiftValveOpeningType",
+    "get_metadata",
     "HydrodynamicModelType",
     "InitialConditionStrategyType",
     "InterpolationType",
+    "LeakLocation",
+    "LeakModel",
+    "LeakType",
     "MassInflowSplitType",
     "MassSourceType",
     "MaterialType",
@@ -411,6 +463,7 @@ __all__ = [
     "SimulationRegimeType",
     "SolidsModelType",
     "SurfaceTensionType",
+    "SurgeVolumeTimeMode",
     "TableInputType",
     "TracerModelType",
     "ValveOpeningType",
@@ -437,6 +490,7 @@ __all__ = [
     "Enum",
     "FileContent",
     "MultipleReference",
+    "BaseField",
     "Quantity",
     "Reference",
     "String",
