@@ -24,7 +24,6 @@ from strictyaml import YAML
 from alfasim_sdk._internal import constants
 from alfasim_sdk._internal.alfacase import case_description
 
-
 T = TypeVar("T")
 
 
@@ -56,10 +55,11 @@ class DescriptionDocument:
         alfacase.schema.case_schema
         """
         import strictyaml
-        from alfasim_sdk._internal.alfacase.schema import case_description_schema
+
         from alfasim_sdk._internal.alfacase.case_description_attributes import (
             DescriptionError,
         )
+        from alfasim_sdk._internal.alfacase.schema import case_description_schema
 
         try:
             content = strictyaml.dirty_load(
@@ -170,7 +170,9 @@ def get_case_description_attribute_loader_dict(
     return loaders
 
 
-def load_scalar(key: str, alfacase_content: DescriptionDocument, category) -> Scalar:
+def load_scalar(
+    key: str, alfacase_content: DescriptionDocument, category: str
+) -> Scalar:
     """
     Create a barril.units.Scalar instance from the given alfacase_content.
     # TODO: ASIM-3556: All atributes from this module should get the category from the CaseDescription
@@ -197,7 +199,7 @@ def get_scalar_loader(
     )
 
 
-def load_array(key: str, alfacase_content: DescriptionDocument, category) -> Array:
+def load_array(key: str, alfacase_content: DescriptionDocument, category: str) -> Array:
     """
     Create a barril.units.Array instance from the given YAML content.
     # TODO: ASIM-3556: All atributes from this module should get the category from the CaseDescription
@@ -225,7 +227,9 @@ def get_array_loader(
 
 
 def load_list_of_arrays(
-    key: str, alfacase_content: DescriptionDocument, category
+    key: str,
+    alfacase_content: DescriptionDocument,
+    category: str,
 ) -> List[Array]:
     """
     Create a barril.units.Array instance from the given YAML content.
@@ -253,7 +257,9 @@ def get_list_of_arrays_loader(
 
 
 def load_dict_of_arrays(
-    key: str, alfacase_content: DescriptionDocument, category
+    key: str,
+    alfacase_content: DescriptionDocument,
+    category: str,
 ) -> Dict[str, Array]:
     """
     Create a Dict of str to barril.units.Array instances from the given YAML content.
@@ -280,7 +286,7 @@ def get_dict_of_arrays_loader(
     )
 
 
-def load_curve(key: str, alfacase_content: DescriptionDocument, category) -> Curve:
+def load_curve(key: str, alfacase_content: DescriptionDocument, category: str) -> Curve:
     """
     Create a barril.curve.curve.Curve instance from the given YAML content.
     # TODO: ASIM-3556: All atributes from this module should get the category from the CaseDescription
@@ -354,7 +360,9 @@ def _obtain_category_for_scalar(category: str, from_unit: str) -> str:
 
 
 def load_dict_with_scalar(
-    key: str, alfacase_content: DescriptionDocument, category
+    key: str,
+    alfacase_content: DescriptionDocument,
+    category: str,
 ) -> Dict[str, Scalar]:
     return {
         key: Scalar(category, value["value"], value["unit"])
@@ -466,7 +474,9 @@ def load_pvt_model_correlation_description(
         ),
     }
 
-    def generate_pvt_model_correlation(value: DescriptionDocument):
+    def generate_pvt_model_correlation(
+        value: DescriptionDocument,
+    ) -> case_description.PvtModelCorrelationDescription:
         case_values = to_case_values(value, alfacase_to_case_description)
         item_description = case_description.PvtModelCorrelationDescription(
             **case_values
@@ -721,6 +731,7 @@ def load_environment_property_description(
         'overall_heat_transfer_coefficient': get_scalar_loader(from_unit='W/m2.K'),
         'fluid_velocity': get_scalar_loader(from_unit='m/s'),
     }
+
     # fmt: on
     def generate_environment_property_description(document: DescriptionDocument):
         case_values = to_case_values(document, alfacase_to_case_description)
@@ -1336,25 +1347,97 @@ def load_table_pump_description(
     return update_multi_input_flags(document, item_description)
 
 
-def load_trend_output_description(
+def generate_trend_description(
     document: DescriptionDocument,
-) -> List[case_description.TrendOutputDescription]:
+    alfacase_to_case_description: Dict[str, Callable],
+    description_type: [T],
+) -> [T]:
+    case_values = to_case_values(document, alfacase_to_case_description)
+    item_description = description_type(**case_values)
+    return update_multi_input_flags(document, item_description)
+
+
+def load_positional_pipe_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.PositionalPipeTrendDescription]:
+    alfacase_to_case_description = get_case_description_attribute_loader_dict(
+        case_description.PositionalPipeTrendDescription
+    )
+    return [
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.PositionalPipeTrendDescription,
+        )
+        for alfacase_document in document
+    ]
+
+
+def load_equipment_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.EquipmentTrendDescription]:
     alfacase_to_case_description = {
         "curve_names": load_value,
-        "location": get_enum_loader(enum_class=constants.OutputAttachmentLocation),
         "element_name": load_value,
-        "position": get_scalar_loader(from_unit="m"),
     }
-
-    def generate_trend_description(
-        document: DescriptionDocument,
-    ) -> case_description.TrendOutputDescription:
-        case_values = to_case_values(document, alfacase_to_case_description)
-        item_description = case_description.TrendOutputDescription(**case_values)
-        return update_multi_input_flags(document, item_description)
-
     return [
-        generate_trend_description(alfacase_document) for alfacase_document in document
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.EquipmentTrendDescription,
+        )
+        for alfacase_document in document
+    ]
+
+
+def load_separator_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.SeparatorTrendDescription]:
+    alfacase_to_case_description = {
+        "curve_names": load_value,
+        "element_name": load_value,
+    }
+    return [
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.SeparatorTrendDescription,
+        )
+        for alfacase_document in document
+    ]
+
+
+def load_global_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.GlobalTrendDescription]:
+    alfacase_to_case_description = {
+        "curve_names": load_value,
+    }
+    return [
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.GlobalTrendDescription,
+        )
+        for alfacase_document in document
+    ]
+
+
+def load_overall_pipe_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.OverallPipeTrendDescription]:
+    alfacase_to_case_description = {
+        "curve_names": load_value,
+        "element_name": load_value,
+        "location": get_enum_loader(enum_class=constants.OutputAttachmentLocation),
+    }
+    return [
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.OverallPipeTrendDescription,
+        )
+        for alfacase_document in document
     ]
 
 
@@ -1416,13 +1499,28 @@ def load_annulus_description(
     return update_multi_input_flags(document, item_description)
 
 
+def load_trends_output_description(
+    document: DescriptionDocument,
+) -> case_description.TrendsOutputDescription:
+    alfacase_to_case_description = {
+        "positional_pipe_trends": load_positional_pipe_trend_description,
+        "equipment_trends": load_equipment_trend_description,
+        "global_trends": load_global_trend_description,
+        "overall_pipe_trends": load_overall_pipe_trend_description,
+        "separator_trends": load_separator_trend_description,
+    }
+    case_values = to_case_values(document, alfacase_to_case_description)
+    item_description = case_description.TrendsOutputDescription(**case_values)
+    return update_multi_input_flags(document, item_description)
+
+
 def load_case_output_description(
     document: DescriptionDocument,
 ) -> case_description.CaseOutputDescription:
     alfacase_to_case_description = {
         "profiles": load_profile_output_description,
-        "trends": load_trend_output_description,
         "profile_frequency": get_scalar_loader(from_unit="s"),
+        "trends": load_trends_output_description,
         "trend_frequency": get_scalar_loader(from_unit="s"),
     }
     case_values = to_case_values(document, alfacase_to_case_description)
@@ -1543,6 +1641,16 @@ def load_formation_description(
     return update_multi_input_flags(document, item_description)
 
 
+def _generate_description(
+    document: DescriptionDocument,
+    alfacase_to_case_description: Dict[str, Callable],
+    description_type: Type[T],
+) -> T:
+    case_values = to_case_values(document, alfacase_to_case_description)
+    item_description = description_type(**case_values)
+    return update_multi_input_flags(document, item_description)
+
+
 def load_pump_equipment_description(
     document: DescriptionDocument,
 ) -> Dict[str, case_description.PumpEquipmentDescription]:
@@ -1560,14 +1668,11 @@ def load_pump_equipment_description(
         "flow_direction": get_enum_loader(enum_class=constants.FlowDirection),
     }
 
-    def generate_pump_description(document: DescriptionDocument):
-        case_values = to_case_values(document, alfacase_to_case_description)
-        item_description = case_description.PumpEquipmentDescription(**case_values)
-        return update_multi_input_flags(document, item_description)
-
     return {
-        key.data: generate_pump_description(
-            DescriptionDocument(value, document.file_path)
+        key.data: _generate_description(
+            DescriptionDocument(value, document.file_path),
+            alfacase_to_case_description,
+            case_description.PumpEquipmentDescription,
         )
         for key, value in document.content.items()
     }
@@ -1580,15 +1685,28 @@ def load_valve_equipment_description(
         case_description.ValveEquipmentDescription
     )
 
-    def generate_valve_description(document: DescriptionDocument):
+    return {
+        key.data: _generate_description(
+            DescriptionDocument(value, document.file_path),
+            alfacase_to_case_description,
+            case_description.ValveEquipmentDescription,
+        )
+        for key, value in document.content.items()
+    }
 
-        case_values = to_case_values(document, alfacase_to_case_description)
-        item_description = case_description.ValveEquipmentDescription(**case_values)
-        return update_multi_input_flags(document, item_description)
+
+def load_pig_equipment_description(
+    document: DescriptionDocument,
+) -> Dict[str, case_description.PigEquipmentDescription]:
+    alfacase_to_case_description = get_case_description_attribute_loader_dict(
+        case_description.PigEquipmentDescription
+    )
 
     return {
-        key.data: generate_valve_description(
-            DescriptionDocument(value, document.file_path)
+        key.data: _generate_description(
+            DescriptionDocument(value, document.file_path),
+            alfacase_to_case_description,
+            case_description.PigEquipmentDescription,
         )
         for key, value in document.content.items()
     }
@@ -1603,13 +1721,13 @@ def load_wall_description(
         "wall_layer_container": load_wall_layer_description,
     }
 
-    def generate_walls_description(document: DescriptionDocument):
-        case_values = to_case_values(document, alfacase_to_case_description)
-        item_description = case_description.WallDescription(**case_values)
-        return update_multi_input_flags(document, item_description)
-
     return [
-        generate_walls_description(alfacase_document) for alfacase_document in document
+        _generate_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.WallDescription,
+        )
+        for alfacase_document in document
     ]
 
 
@@ -1618,15 +1736,18 @@ def load_equipment_description(
 ) -> case_description.EquipmentDescription:
     alfacase_to_case_description = {
         "mass_sources": load_mass_source_equipment_description,
+        "pigs": load_pig_equipment_description,
         "pumps": load_pump_equipment_description,
         "valves": load_valve_equipment_description,
         "reservoir_inflows": load_reservoir_inflow_equipment_description,
         "heat_sources": load_heat_source_equipment_description,
         "compressors": load_compressor_equipment_description,
     }
-    case_values = to_case_values(document, alfacase_to_case_description)
-    item_description = case_description.EquipmentDescription(**case_values)
-    return update_multi_input_flags(document, item_description)
+    return _generate_description(
+        document,
+        alfacase_to_case_description,
+        case_description.EquipmentDescription,
+    )
 
 
 def load_x_and_y_description(
@@ -1636,9 +1757,11 @@ def load_x_and_y_description(
         "x": get_array_loader(from_unit="m"),
         "y": get_array_loader(from_unit="m"),
     }
-    case_values = to_case_values(document, alfacase_to_case_description)
-    item_description = case_description.XAndYDescription(**case_values)
-    return update_multi_input_flags(document, item_description)
+    return _generate_description(
+        document,
+        alfacase_to_case_description,
+        case_description.XAndYDescription,
+    )
 
 
 def load_length_and_elevation_description(
@@ -1648,9 +1771,11 @@ def load_length_and_elevation_description(
         "length": get_array_loader(from_unit="m"),
         "elevation": get_array_loader(from_unit="m"),
     }
-    case_values = to_case_values(document, alfacase_to_case_description)
-    item_description = case_description.LengthAndElevationDescription(**case_values)
-    return update_multi_input_flags(document, item_description)
+    return _generate_description(
+        document,
+        alfacase_to_case_description,
+        case_description.LengthAndElevationDescription,
+    )
 
 
 def load_profile_description(
@@ -1682,6 +1807,7 @@ def load_pipe_description(
         "source_port": get_enum_loader(enum_class=constants.WellConnectionPort),
         "target_port": get_enum_loader(enum_class=constants.WellConnectionPort),
     }
+
     # fmt: on
     def generate_pipes_description(document: DescriptionDocument):
         case_values = to_case_values(document, alfacase_to_case_description)
@@ -1766,6 +1892,7 @@ def load_numerical_options_description(document: DescriptionDocument) -> case_de
     return update_multi_input_flags(document, item_description)
 # fmt: on
 
+
 # fmt: off
 def load_time_options_description(
     document: DescriptionDocument
@@ -1784,7 +1911,6 @@ def load_time_options_description(
     item_description = case_description.TimeOptionsDescription(**case_values)
     return update_multi_input_flags(document, item_description)
 
-
 # fmt: on
 
 
