@@ -207,4 +207,6 @@ EquipmentTypes = Union[
     case_description.ValveEquipmentDescription,
     case_description.PumpEquipmentDescription,
     case_description.GasLiftValveEquipmentDescription,
+    case_description.LeakEquipmentDescription,
+    case_description.PigEquipmentDescription,
 ]
