@@ -51,6 +51,23 @@ compressor_pressure_table_description_schema = Map(
         Optional("isentropic_efficiency_table"): Map({"values": Seq(Float()), "unit": Str()}),
     }
 )
+controller_input_signal_properties_description_schema = Map(
+    {
+        Optional("target_variable"): Str(),
+        Optional("input_trend_name"): Str(),
+        Optional("unit"): Str(),
+    }
+)
+controller_output_signal_properties_description_schema = Map(
+    {
+        Optional("controlled_property"): Str(),
+        Optional("unit"): Str(),
+        Optional("network_element_name"): Str(),
+        Optional("min_value"): Float(),
+        Optional("max_value"): Float(),
+        Optional("max_rate_of_change"): Float(),
+    }
+)
 cv_table_description_schema = Map(
     {
         Optional("opening"): Map({"values": Seq(Float()), "unit": Str()}),
@@ -67,6 +84,13 @@ environment_property_description_schema = Map(
         Optional("fluid_velocity"): Map({"value": Float(), "unit": Str()}),
     }
 )
+equipment_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+        "element_name": Str(),
+    }
+)
 formation_layer_description_schema = Map(
     {
         "name": Str(),
@@ -83,6 +107,12 @@ gas_lift_valve_equipment_description_schema = Map(
         "discharge_coeff": Map({"value": Float(), "unit": Str()}),
     }
 )
+global_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+    }
+)
 heat_source_equipment_description_schema = Map(
     {
         "start": Map({"value": Float(), "unit": Str()}),
@@ -314,6 +344,14 @@ open_hole_description_schema = Map(
         "inner_roughness": Map({"value": Float(), "unit": Str()}),
     }
 )
+overall_pipe_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+        "location": Enum(['main', 'annulus', 'not_defined']),
+        "element_name": Str(),
+    }
+)
 packer_description_schema = Map(
     {
         "name": Str(),
@@ -336,6 +374,58 @@ physics_description_schema = Map(
         Optional("correlations_package"): Enum(['correlation_package_classical', 'correlation_package_alfasim', 'correlation_package_isdb_tests']),
     }
 )
+pig_equipment_description_schema = Map(
+    {
+        "diameter": Map({"value": Float(), "unit": Str()}),
+        "position": Map({"value": Float(), "unit": Str()}),
+        Optional("launch_times"): Map({"values": Seq(Float()), "unit": Str()}),
+        Optional("mass_input_type"): Enum(['constant', 'curve']),
+        Optional("mass"): Map({"value": Float(), "unit": Str()}),
+        Optional("mass_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("static_force_input_type"): Enum(['constant', 'curve']),
+        Optional("static_force"): Map({"value": Float(), "unit": Str()}),
+        Optional("static_force_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("wall_friction_input_type"): Enum(['constant', 'curve']),
+        Optional("wall_friction"): Map({"value": Float(), "unit": Str()}),
+        Optional("wall_friction_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("linear_friction_input_type"): Enum(['constant', 'curve']),
+        Optional("linear_friction"): Map({"value": Float(), "unit": Str()}),
+        Optional("linear_friction_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("quadratic_friction_input_type"): Enum(['constant', 'curve']),
+        Optional("quadratic_friction"): Map({"value": Float(), "unit": Str()}),
+        Optional("quadratic_friction_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("trap_mode"): Enum(['automatic', 'user_defined']),
+        Optional("trap_position"): Map({"value": Float(), "unit": Str()}),
+        Optional("trap_pipe_name"): Str(),
+        Optional("route_mode"): Enum(['automatic', 'user_defined']),
+        Optional("pipe_route_names"): Seq(Str()),
+    }
+)
 pipe_segments_description_schema = Map(
     {
         "start_positions": Map({"values": Seq(Float()), "unit": Str()}),
@@ -422,8 +512,8 @@ pressure_node_properties_description_schema = Map(
 profile_output_description_schema = Map(
     {
         "curve_names": Seq(Str()),
-        "element_name": Str(),
         "location": Enum(['main', 'annulus', 'not_defined']),
+        "element_name": Str(),
     }
 )
 pvt_model_correlation_description_schema = Map(
@@ -555,12 +645,28 @@ separator_node_properties_description_schema = Map(
         Optional("liquid_separation_efficiency"): Map({"value": Float(), "unit": Str()}),
     }
 )
+separator_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+        "element_name": Str(),
+    }
+)
 speed_curve_description_schema = Map(
     {
         Optional("time"): Map({"values": Seq(Float()), "unit": Str()}),
         Optional("speed"): Map({"values": Seq(Float()), "unit": Str()}),
     }
 )
+surge_volume_options_description_schema = Map(
+    {
+        Optional("time_mode"): Enum(['all_simulation', 'user_defined']),
+        Optional("drainage_mode"): Enum(['automatic', 'user_defined']),
+        Optional("start_time"): Map({"value": Float(), "unit": Str()}),
+        Optional("end_time"): Map({"value": Float(), "unit": Str()}),
+        Optional("maximum_drainage_rate"): Map({"value": Float(), "unit": Str()}),
+    }
+)
 table_pump_description_schema = Map(
     {
         Optional("speeds"): Map({"values": Seq(Float()), "unit": Str()}),
@@ -599,14 +705,6 @@ tracers_mass_fractions_container_description_schema = Map(
         Optional("tracers_mass_fractions"): Seq(Map({"values": Seq(Float()), "unit": Str()})),
     }
 )
-trend_output_description_schema = Map(
-    {
-        "curve_names": Seq(Str()),
-        "location": Enum(['main', 'annulus', 'not_defined']),
-        Optional("position"): Map({"value": Float(), "unit": Str()}),
-        Optional("element_name"): Str(),
-    }
-)
 tubing_description_schema = Map(
     {
         "name": Str(),
@@ -642,16 +740,6 @@ x_and_y_description_schema = Map(
         Optional("y"): Map({"values": Seq(Float()), "unit": Str()}),
     }
 )
-case_output_description_schema = Map(
-    {
-        Optional("automatic_trend_frequency"): Bool(),
-        Optional("trends"): Seq(trend_output_description_schema),
-        Optional("trend_frequency"): Map({"value": Float(), "unit": Str()}),
-        Optional("automatic_profile_frequency"): Bool(),
-        Optional("profiles"): Seq(profile_output_description_schema),
-        Optional("profile_frequency"): Map({"value": Float(), "unit": Str()}),
-    }
-)
 casing_description_schema = Map(
     {
         Optional("casing_sections"): Seq(casing_section_description_schema),
@@ -673,6 +761,17 @@ compressor_equipment_description_schema = Map(
         Optional("table"): compressor_pressure_table_description_schema,
     }
 )
+controller_node_properties_description_schema = Map(
+    {
+        Optional("type"): Enum(['pid']),
+        Optional("gain"): Float(),
+        Optional("setpoint"): Float(),
+        Optional("integral_time"): Map({"value": Float(), "unit": Str()}),
+        Optional("derivative_time"): Map({"value": Float(), "unit": Str()}),
+        Optional("input_signal_properties"): controller_input_signal_properties_description_schema,
+        Optional("output_signal_properties"): controller_output_signal_properties_description_schema,
+    }
+)
 environment_description_schema = Map(
     {
         Optional("thermal_model"): Enum(['adiabatic_walls', 'steady_state_heat_transfer', 'transient_heat_transfer']),
@@ -734,15 +833,43 @@ initial_volume_fractions_description_schema = Map(
         Optional("table_length"): volume_fractions_container_description_schema,
     }
 )
-node_description_schema = Map(
+leak_equipment_description_schema = Map(
     {
-        "name": Str(),
-        "node_type": Enum(['internal_node', 'mass_source_boundary', 'pressure_boundary', 'separator_node']),
-        Optional("pvt_model"): Str(),
-        Optional("pressure_properties"): pressure_node_properties_description_schema,
-        Optional("mass_source_properties"): mass_source_node_properties_description_schema,
-        Optional("internal_properties"): internal_node_properties_description_schema,
-        Optional("separator_properties"): separator_node_properties_description_schema,
+        "position": Map({"value": Float(), "unit": Str()}),
+        Optional("location"): Enum(['main', 'annulus', 'not_defined']),
+        Optional("model"): Enum(['orifice', 'flow_coefficient', 'gas_lift_valve']),
+        Optional("type"): Enum(['internal', 'external']),
+        Optional("diameter"): Map({"value": Float(), "unit": Str()}),
+        Optional("discharge_coefficient"): Map({"value": Float(), "unit": Str()}),
+        Optional("cv_table"): cv_table_description_schema,
+        Optional("gas_lift_valve_opening_type"): Enum(['minimum_pressure_difference', 'pressure_operated']),
+        Optional("minimum_pressure_difference"): Map({"value": Float(), "unit": Str()}),
+        Optional("bellows_reference_pressure"): Map({"value": Float(), "unit": Str()}),
+        Optional("bellows_reference_temperature"): Map({"value": Float(), "unit": Str()}),
+        Optional("port_to_bellows_area_ratio"): Map({"value": Float(), "unit": Str()}),
+        Optional("opening_input_type"): Enum(['constant', 'curve']),
+        Optional("opening"): Map({"value": Float(), "unit": Str()}),
+        Optional("opening_curve"): Map(
+            {
+                "image": Map({"values": Seq(Float()), "unit": Str()}),
+                "domain": Map({"values": Seq(Float()), "unit": Str()}),
+            }
+        ),
+        Optional("target_pipe_name"): Str(),
+        Optional("target_position"): Map({"value": Float(), "unit": Str()}),
+        Optional("target_location"): Enum(['main', 'annulus', 'not_defined']),
+        Optional("backflow"): Bool(),
+        Optional("backpressure"): Map({"value": Float(), "unit": Str()}),
+    }
+)
+positional_pipe_trend_description_schema = Map(
+    {
+        Optional("name"): Str(),
+        "curve_names": Seq(Str()),
+        "location": Enum(['main', 'annulus', 'not_defined']),
+        "position": Map({"value": Float(), "unit": Str()}),
+        "element_name": Str(),
+        Optional("surge_volume_options"): surge_volume_options_description_schema,
     }
 )
 profile_description_schema = Map(
@@ -807,6 +934,8 @@ equipment_description_schema = Map(
         Optional("reservoir_inflows"): MapPattern(Str(), reservoir_inflow_equipment_description_schema),
         Optional("heat_sources"): MapPattern(Str(), heat_source_equipment_description_schema),
         Optional("compressors"): MapPattern(Str(), compressor_equipment_description_schema),
+        Optional("leaks"): MapPattern(Str(), leak_equipment_description_schema),
+        Optional("pigs"): MapPattern(Str(), pig_equipment_description_schema),
     }
 )
 ipr_models_description_schema = Map(
@@ -825,6 +954,18 @@ initial_conditions_description_schema = Map(
         Optional("fluid"): Str(),
     }
 )
+node_description_schema = Map(
+    {
+        "name": Str(),
+        "node_type": Enum(['internal_node', 'mass_source_boundary', 'pressure_boundary', 'separator_node', 'controller_node']),
+        Optional("pvt_model"): Str(),
+        Optional("pressure_properties"): pressure_node_properties_description_schema,
+        Optional("mass_source_properties"): mass_source_node_properties_description_schema,
+        Optional("internal_properties"): internal_node_properties_description_schema,
+        Optional("separator_properties"): separator_node_properties_description_schema,
+        Optional("controller_properties"): controller_node_properties_description_schema,
+    }
+)
 pvt_model_compositional_description_schema = Map(
     {
         Optional("equation_of_state_type"): Enum(['pvt_compositional_peng_robinson', 'pvt_compositional_soave_redlich_kwong']),
@@ -835,6 +976,15 @@ pvt_model_compositional_description_schema = Map(
         Optional("fluids"): MapPattern(Str(), fluid_description_schema),
     }
 )
+trends_output_description_schema = Map(
+    {
+        Optional("positional_pipe_trends"): Seq(positional_pipe_trend_description_schema),
+        Optional("overall_pipe_trends"): Seq(overall_pipe_trend_description_schema),
+        Optional("global_trends"): Seq(global_trend_description_schema),
+        Optional("equipment_trends"): Seq(equipment_trend_description_schema),
+        Optional("separator_trends"): Seq(separator_trend_description_schema),
+    }
+)
 annulus_description_schema = Map(
     {
         "has_annulus_flow": Bool(),
@@ -844,6 +994,16 @@ annulus_description_schema = Map(
         "top_node": Str(),
     }
 )
+case_output_description_schema = Map(
+    {
+        Optional("automatic_trend_frequency"): Bool(),
+        Optional("trends"): trends_output_description_schema,
+        Optional("trend_frequency"): Map({"value": Float(), "unit": Str()}),
+        Optional("automatic_profile_frequency"): Bool(),
+        Optional("profiles"): Seq(profile_output_description_schema),
+        Optional("profile_frequency"): Map({"value": Float(), "unit": Str()}),
+    }
+)
 pipe_description_schema = Map(
     {
         "name": Str(),
@@ -900,5 +1060,5 @@ case_description_schema = Map(
         Optional("walls"): Seq(wall_description_schema),
     }
 )
-# [[[end]]] (checksum: 710fb058c518db160703194f4a2e87fc)
+# [[[end]]] (checksum: 7831a597443e52a67a878e61ea546187)
 # fmt: on
