@@ -141,6 +141,7 @@ class NodeCellType(Enum):
     MassSource = "mass_source_boundary"
     Pressure = "pressure_boundary"
     Separator = "separator_node"
+    Controller = "controller_node"
 
 
 class MassInflowSplitType(Enum):
@@ -251,6 +252,28 @@ class FlashModel(Enum):
     HydrocarbonAndWater = "hydrocarbon_and_water"
 
 
+class DrainageRateMode(Enum):
+    """
+    Drainage Rate mode used by Surge Volume curves calculation.
+    """
+
+    #: Uses a default drain flow rate = (AccLiq(end_time) - AccLiq(start_time))/(end_time - start_time)
+    Automatic = "automatic"
+    #: Allows the user to input a maximum drainage rate
+    UserDefined = "user_defined"
+
+
+class SurgeVolumeTimeMode(Enum):
+    """
+    Time mode used by Surge Volume curves calculation.
+    """
+
+    #: Uses the initial and final time of the whole simulation.
+    AllSimulation = "all_simulation"
+    #: Uses custom initial/final time input by the user.
+    UserDefined = "user_defined"
+
+
 class FlowDirection(Enum):
     Forward = "forward"
     Backward = "backward"
@@ -321,6 +344,22 @@ class ValveType(Enum):
     CheckValve = "check_valve"
 
 
+class LeakModel(Enum):
+    Orifice = "orifice"
+    FlowCoefficient = "flow_coefficient"
+    GasLiftValve = "gas_lift_valve"
+
+
+class LeakType(Enum):
+    Internal = "internal"
+    External = "external"
+
+
+class GasLiftValveOpeningType(Enum):
+    MinimumPressureDifference = "minimum_pressure_difference"
+    PressureOperated = "pressure_operated"
+
+
 class CompressorSpeedType(Enum):
     SpeedCurve = "speed_curve"
     ConstantSpeed = "constant_speed"
@@ -336,6 +375,9 @@ class OutputAttachmentLocation(Enum):
     NotDefined = "not_defined"
 
 
+LeakLocation = OutputAttachmentLocation
+
+
 class CorrelationPackage(Enum):
     Lasater = "pvt_correlation_package_lasater"
     Standing = "pvt_correlation_package_standing"
@@ -371,4 +413,36 @@ class WellConnectionPort(Enum):
     RightAnnulus = "right_annulus_port"
 
 
+class ControllerType(Enum):
+    PID = "pid"
+
+
+class PigTrappingMode(Enum):
+    """
+    Trapping mode of a PIG equipment.
+    """
+
+    #: The PIG is automatically trapped whenever it reaches a boundary node (e.g.,
+    #: pressure or mass boundary).
+    Automatic = "automatic"
+
+    #: The PIG is trapped according to user-defined pipe and position unless it
+    #: reaches a boundary node first.
+    UserDefined = "user_defined"
+
+
+class PigRoutingMode(Enum):
+    """
+    Trapping mode of a PIG equipment.
+    """
+
+    #: When a PIG encounters an internal node, the next pipe in which the PIG goes to
+    #: is selected based on the pipe with greatest total mass flow rate at that point.
+    Automatic = "automatic"
+
+    #: When a PIG encounters an internal node, the next pipe in which the PIG goes
+    #: to is selected based on a user-defined trajectory (edge group).
+    UserDefined = "user_defined"
+
+
 MULTI_INPUT_TYPE_SUFFIX = "_input_type"
