@@ -27,9 +27,16 @@ typedef int (*get_plugin_data_func)(void*, void**, const char*, int);
 typedef int (*get_number_of_threads_func)(void*, int*);
 typedef int (*get_plugin_variable_func)(void* ctx, void** out, const char* variable_name, int line_index, int timestep, int* size);
 typedef int (*get_field_id_func)(void* ctx, int* out, const char* name);
-typedef int (*get_primary_field_id_of_phase_func)(void* ctx, int* out, const char* name);
 typedef int (*get_phase_id_func)(void* ctx, int* out, const char* name);
 typedef int (*get_layer_id_func)(void* ctx, int* out, const char* name);
+typedef int (*get_number_of_fields_func)(void*, int*);
+typedef int (*get_number_of_phases_func)(void*, int*);
+typedef int (*get_number_of_layers_func)(void*, int*);
+typedef int (*get_number_of_phase_pairs_func)(void*, int*);
+typedef int (*get_primary_field_id_of_phase_func)(void* ctx, int* out, const char* name);
+typedef int (*get_phase_id_of_fields_func)(void* ctx, int** out, int* size);
+typedef int (*get_field_ids_in_layer_func)(void* ctx, int** out, int layer_id, int* size);
+typedef int (*get_phase_pair_id_func)(void* ctx, int* out, int phase_0_id, int phase_1_id);
 typedef int (*get_state_variable_array_func)(
     void* ctx,
     double** out,
@@ -117,9 +124,16 @@ struct ALFAsimSDK_API {
     get_plugin_variable_func get_plugin_variable;
 
     get_field_id_func get_field_id;
-    get_primary_field_id_of_phase_func get_primary_field_id_of_phase;
     get_phase_id_func get_phase_id;
     get_layer_id_func get_layer_id;
+    get_number_of_fields_func get_number_of_fields;
+    get_number_of_phases_func get_number_of_phases;
+    get_number_of_layers_func get_number_of_layers;
+    get_number_of_phase_pairs_func get_number_of_phase_pairs;
+    get_primary_field_id_of_phase_func get_primary_field_id_of_phase;
+    get_phase_id_of_fields_func get_phase_id_of_fields;
+    get_field_ids_in_layer_func get_field_ids_in_layer;
+    get_phase_pair_id_func get_phase_pair_id;
 
     get_state_variable_array_func get_state_variable_array;
     get_simulation_array_func get_simulation_array;
